import * as Types from './json-types';
export declare type PromiseOrValue<T> = T | PromiseLike<T>;
export declare const PromiseOrValue: Readonly<{
    map: <T, U>(promiseOrValue: PromiseOrValue<T>, onFulfilled: (T: any) => PromiseOrValue<U>) => PromiseOrValue<U>;
    then: <T, U>(action: () => PromiseOrValue<T>, onFulfilled: (T: any) => PromiseOrValue<U>, onRejected?: (reason: any) => any) => any;
    catch: <T>(action: () => PromiseOrValue<T>, onRejected: (reason: any) => any) => any;
}>;
export declare type Handler = (event: Types.RequestBody) => PromiseOrValue<Types.ResponseBody | void>;
export declare type Pipe = (event: Types.RequestBody, next: Handler) => PromiseOrValue<Types.ResponseBody | void>;
export interface Speech {
    Text?: string;
    SSML?: string;
}
export interface LinkAccount {
    Type: 'LinkAccount';
}
export interface CardImage {
    SmallUrl: string;
    LargeUrl: string;
}
export declare type Card = LinkAccount | {
    Type: 'Card';
    Title: string;
    Content: string;
    Image?: CardImage;
};
export interface Response<State> {
    Say?: Speech;
    NewState?: State;
    Reprompt?: Speech;
    Card?: Card;
    EndSession?: boolean;
}
export declare type HandlerResult<State> = PromiseOrValue<Response<State> | Types.ResponseBody | void>;
export declare type Slots = Map<string, any>;
export declare type IntentHandler<State> = (sessionState: State, slots: Slots, request: Types.RequestBody, next: Handler) => HandlerResult<State>;
export interface StandardIntentRoutes<State> {
    Cancel?: IntentHandler<State>;
    Help?: IntentHandler<State>;
    LoopOff?: IntentHandler<State>;
    LoopOn?: IntentHandler<State>;
    Next?: IntentHandler<State>;
    No?: IntentHandler<State>;
    Pause?: IntentHandler<State>;
    Previous?: IntentHandler<State>;
    Repeat?: IntentHandler<State>;
    Resume?: IntentHandler<State>;
    ShuffleOff?: IntentHandler<State>;
    ShuffleOn?: IntentHandler<State>;
    StartOver?: IntentHandler<State>;
    Stop?: IntentHandler<State>;
    Yes?: IntentHandler<State>;
}
export interface Routes<State> {
    InitialState: State;
    Launch?: IntentHandler<State>;
    SessionEnded?: () => PromiseOrValue<void>;
    Standard?: StandardIntentRoutes<State>;
    Custom?: Iterable<[string, IntentHandler<State>]>;
}
export declare const State: Readonly<{
    attributeKey: string;
    fromRequest: <State>(request: Types.RequestBody, initialState?: State) => any;
}>;
export declare const response: <State>(response: Response<State>, previousState?: State) => Types.ResponseBody;
export declare const Pipe: Readonly<{
    join: (steps: Pipe[]) => Pipe;
    toHandler: (pipe: Pipe) => Handler;
    router: <State>(routes: Routes<State>) => Pipe;
    tracer: (logger?: (message: string, obj: any) => void) => Pipe;
    doNothing: () => Pipe;
}>;
export declare const Handler: Readonly<{
    middleware: (pipe: Pipe) => Handler;
    router: <State>(routes: Routes<State>) => Handler;
    pipe: (steps: Pipe[]) => Handler;
}>;
export declare const Lambda: Readonly<{
    handler: (handler: Handler) => Types.AlexaLambda;
    router: <State>(routes: Routes<State>) => Types.AlexaLambda;
    pipe: (steps: Pipe[]) => Types.AlexaLambda;
}>;
